import * as React from "react";
import { TextFieldVariants } from "@mui/material";
import * as BestGlobals from "best-globals";
export interface FieldDefinition {
    name: string;
    typeName: 'text' | 'decimal' | 'boolean' | 'date' | 'bigint';
    title: string;
    nullable: boolean;
    allowEmptyText: boolean;
    allow: {
        update: boolean;
    };
    references: string;
    suggestingKeys: string[];
}
export interface TableDefinition {
    fields: FieldDefinition[];
    primaryKey: string[];
}
export type RecordStatus = 'new' | 'update';
export interface BEAPI {
    table_structure: (params: {
        table: string;
    }) => Promise<TableDefinition>;
    table_data: (params: {
        table: string;
        fixedFields: RowType;
        paramfun: {};
    }) => Promise<RowType[]>;
    table_record_save: (params: {
        table: string;
        primaryKeyValues: any[];
        newRow: RowType;
        oldRow: RowType;
        status: RecordStatus;
    }) => Promise<{
        row: RowType;
    }>;
    option_lists: (params: {
        table: string;
    }) => Promise<OptionsInfo>;
}
export interface Connector {
    ajax: BEAPI;
}
export interface AddrParams {
    table: string;
    ff: Record<string, any> | {
        fieldName: string;
        value: any;
    }[];
}
export declare const ICON: {
    Add: () => React.JSX.Element;
    AddCircleOutlineRounded: () => React.JSX.Element;
    ArrowBack: () => React.JSX.Element;
    Assignment: () => React.JSX.Element;
    Check: () => React.JSX.Element;
    CheckBoxOutlineBlankOutlined: () => React.JSX.Element;
    CheckBoxOutlined: () => React.JSX.Element;
    ChevronLeft: () => React.JSX.Element;
    ChevronRight: () => React.JSX.Element;
    Clear: () => React.JSX.Element;
    Close: () => React.JSX.Element;
    Code: () => React.JSX.Element;
    ComputerRounded: () => React.JSX.Element;
    Create: () => React.JSX.Element;
    Delete: () => React.JSX.Element;
    DeleteForever: () => React.JSX.Element;
    DeleteOutline: () => React.JSX.Element;
    Description: () => React.JSX.Element;
    EmojiObjects: () => React.JSX.Element;
    ErrorOutlineRounded: () => React.JSX.Element;
    ExitToApp: () => React.JSX.Element;
    ExpandLess: () => React.JSX.Element;
    ExpandMore: () => React.JSX.Element;
    FormatLineSpacing: () => React.JSX.Element;
    Forward: () => React.JSX.Element;
    ForwardOutlined: () => React.JSX.Element;
    Info: () => React.JSX.Element;
    KeyboardArrowUp: () => React.JSX.Element;
    KeyboardArrowDown: () => React.JSX.Element;
    KeyboardHideRounded: () => React.JSX.Element;
    Label: () => React.JSX.Element;
    LocalAtm: () => React.JSX.Element;
    Menu: () => React.JSX.Element;
    MobileFriendlyRounded: () => React.JSX.Element;
    Navigation: () => React.JSX.Element;
    NavigationDown: () => React.JSX.Element;
    RemoveShoppingCart: () => React.JSX.Element;
    Save: () => React.JSX.Element;
    Search: () => React.JSX.Element;
    Send: () => React.JSX.Element;
    Settings: () => React.JSX.Element;
    SyncAlt: () => React.JSX.Element;
    TrendingFlat: () => React.JSX.Element;
    Warning: () => React.JSX.Element;
};
export declare function MenuH(props: {
    title: string;
    rightTitle?: string;
    mobile: boolean;
    onMobile: (mobile: boolean) => void;
}): React.JSX.Element;
export declare function ComboBox(props: {
    key: string;
    value: string | null;
    valueOfNull: string | null;
    onChange: (newValue: null | string) => void;
    options: string[];
    label: string;
    freeSolo: boolean;
    disabled: boolean;
    helperText?: string;
    variant?: TextFieldVariants;
    className?: string;
    title?: string;
    mobile: boolean;
}): React.JSX.Element;
type FieldTypes = null | string | boolean | number | BestGlobals.RealDate;
type RowType = Record<string, FieldTypes>;
export declare function CardEditor(props: {
    updatesToRow: RowType;
    originalRow: RowType;
    onRowChange: (row: RowType) => void;
    tableDef: TableDefinition;
    lists: (name: string, row: RowType) => string[];
    forEdit: boolean;
    mobile: boolean;
}): React.JSX.Element;
type OptionsInfo = {
    chained?: RowType;
    relations?: Record<string, string[]>;
};
export declare function CardEditorConnected(props: {
    table: string;
    fixedFields: RowType;
    conn: Connector;
}): React.JSX.Element;
export declare function renderCardEditor(conn: Connector, addrParams: AddrParams, layout: HTMLElement): void;
export {};
//# sourceMappingURL=frontend-plus.d.ts.map